# mypy-boto3-shield

[![PyPI - mypy-boto3-shield](https://img.shields.io/pypi/v/mypy-boto3-shield.svg?color=blue)](https://pypi.org/project/mypy-boto3-shield)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-shield.svg?color=blue)](https://pypi.org/project/mypy-boto3-shield)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Shield 1.15.13](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/shield.html#Shield) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.2.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-shield](#mypy-boto3-shield)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Shield` service.

```bash
python -m pip install boto3-stubs[shield]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[shield]` in your environment: `python -m pip install 'boto3-stubs[shield]'`

Both type checking and auto-complete should work for `Shield` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[shield]` in your environment: `python -m pip install 'boto3-stubs[shield]'`

Both type checking and auto-complete should work for `Shield` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[shield]` in your environment: `python -m pip install 'boto3-stubs[shield]'`
- Run `mypy` as usual

Type checking should work for `Shield` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[shield]` in your environment: `python -m pip install 'boto3-stubs[shield]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Shield` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`ShieldClient` provides annotations for `boto3.client("shield")`.

```python
import boto3

from mypy_boto3_shield import ShieldClient

client: ShieldClient = boto3.client("shield")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ShieldClient = session.client("shield")
```

### Paginators annotations

`mypy_boto3_shield.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_shield import ShieldClient
from mypy_boto3_shield.paginator import ListAttacksPaginator, ListProtectionsPaginator

client: ShieldClient = boto3.client("shield")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_attacks_paginator: ListAttacksPaginator = client.get_paginator("list_attacks")
list_protections_paginator: ListProtectionsPaginator = client.get_paginator("list_protections")
```







### Typed dictionations

`mypy_boto3_shield.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_shield.type_defs import (
    AttackDetailTypeDef,
    AttackPropertyTypeDef,
    AttackSummaryTypeDef,
    AttackVectorDescriptionTypeDef,
    ContributorTypeDef,
    CreateProtectionResponseTypeDef,
    DescribeAttackResponseTypeDef,
    DescribeDRTAccessResponseTypeDef,
    DescribeEmergencyContactSettingsResponseTypeDef,
    DescribeProtectionResponseTypeDef,
    DescribeSubscriptionResponseTypeDef,
    EmergencyContactTypeDef,
    GetSubscriptionStateResponseTypeDef,
    LimitTypeDef,
    ListAttacksResponseTypeDef,
    ListProtectionsResponseTypeDef,
    MitigationTypeDef,
    PaginatorConfigTypeDef,
    ProtectionTypeDef,
    SubResourceSummaryTypeDef,
    SubscriptionTypeDef,
    SummarizedAttackVectorTypeDef,
    SummarizedCounterTypeDef,
    TimeRangeTypeDef,
)

def get_structure() -> AttackDetailTypeDef:
    return {
      ...
    }
```
